@@ -134,7 +134,7 @@ class SHCAPI:
             }
 
         try:
-            result = self._post_api_or_fail(api_url, data)
+            result = await self._post_api_or_fail(api_url, data)
         except Exception as e:
             logging.error(f"Failed to set temperature for device with id: {device.unique_id}")
             return None
@@ -152,7 +152,7 @@ class SHCAPI:
                 ]
             }
         try:
-            result = self._post_api_or_fail(api_url, data)
+            result = await self._post_api_or_fail(api_url, data)
         except Exception as e:
             logging.error(f"Failed to set mode for device with id: {device.unique_id}")
             return None
@@ -169,10 +169,10 @@ class SHCAPI:
                             "SetHoldType": 7 if preset == PRESET_OFF else 2 if preset == PRESET_PERMANENT_HOLD else 0
                         }
                     }
-                ],
+                ]
             }
         try:
-            result = self._post_api_or_fail(api_url, data)
+            result = await self._post_api_or_fail(api_url, data)
         except Exception as e:
             logging.error(f"Failed to set preset for device with id: {device.unique_id}")
             return None
