@@ -93,13 +93,13 @@ class SALUSThermostat(SALUSDevice):
         self.summary()
 
     async def set_temperature(self, celsius: float):
-        return await self._api.set_temperature(self, celsius)
+        await self._api.set_temperature(self, celsius)
 
     async def set_climate_device_mode(self, mode: str):
-        return await self._api.set_climate_device_mode(self, mode)
+        await self._api.set_climate_device_mode(self, mode)
 
     async def set_climate_device_preset(self, preset: str):
-        return await self._api.set_climate_device_preset(self, preset)
+        await self._api.set_climate_device_preset(self, preset)
 
 
 MODEL_MAPPING = {
